@@ -26,9 +26,9 @@ from .typing import Dict, Tuple, Union
 # https://github.com/brainelectronics/micropython-modbus/
 # upip.install('micropython-modbus')
 from umodbus.serial import Serial as ModbusRTUMaster
+from umodbus.serial import ModbusRTU
 from umodbus.tcp import TCP as ModbusTCPMaster
-from umodbus.modbus import ModbusRTU
-from umodbus.modbus import ModbusTCP
+from umodbus.tcp import ModbusTCP
 
 
 class ModbusBridgeError(Exception):
